<!-- markdownlint-disable -->

<a href="..\..\qtstrap\widgets\__init__.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `widgets`




**Global Variables**
---------------
- **layouts**
- **buttons**
- **labeledit**
- **link_label**
- **line_widgets**
- **persistent_widgets**
- **persistent_tab_widget**




---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
